"widenet" Objects
"widenet" object.
"predict"(object, newx, order = object$which.order.min, alpha.val = object$which.alpha.min, type = c("link", "response", "coefficients", "nonzero", "class"),
...)"widenet" object from which to get predictions.
x at which predictions are to be made. Must be a matrix; sparse matrices are not yet supported. This argument is not used for type=c("coefficients","nonzero")
order argument for the object. The default is to use that order which "won" the cross-validation.
alpha at which predictions are required. Default is to use that value which "won" the cross-validation.
link[glmnet]{predict.glmnet}.
predict.cv.relaxnet, which should be passed through to predict.glmnet. However, in the current version, these are not guaranteed to work correctly (for example, offset has not yet been implemented for widenet).
widenet, predict.cv.relaxnet, predict.glmnet